package cn.com.ty.lift.business.contract.controller;

import cn.com.ty.lift.business.contract.dao.entity.Contracts;
import cn.com.ty.lift.business.contract.dao.entity.model.ContractRequest;
import cn.com.ty.lift.business.contract.dao.entity.model.ContractsHistoryRequest;
import cn.com.ty.lift.business.contract.service.ContractService;
import cn.com.xwy.boot.web.dto.RestResponse;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

/**
 * @author bieao
 * @date 2019/12/07
 * @description 合同管理控制层
 */
@RestController
@RequestMapping("contract")
public class ContractController {

    @Resource
    private ContractService contractService;


    /**
     * @param request 合同列表查询条件
     * @return RestResponse 合同分页列表结果
     * @description 查询合同列表
     * @date 2019/12/7 11:53 AM
     */
    @PostMapping("list")
    public RestResponse list(@RequestBody ContractRequest request) {
        return contractService.list(request);
    }

    /**
     * @param request 合同操作记录列表查询条件
     * @return RestResponse 合同操作记录分页列表结果
     * @description 查询合同操作记录列表
     * @date 2019/12/7 11:53 AM
     */
    @PostMapping("history/list")
    public RestResponse list(@RequestBody ContractsHistoryRequest request) {
        return contractService.list(request);
    }


    /**
     * @param contracts 新增/续签合同数据项
     * @return 1.成功, 0.失败, 消息描述
     * @description 新增/续签合同
     * @date 2019/12/7 3:31 PM
     */
    @PostMapping("add")
    public RestResponse add(@RequestBody Contracts contracts) {
        return contractService.add(contracts);
    }


    /**
     * @param contracts 修改合同数据项
     * @return 1.成功, 0.失败, 消息描述
     * @description 合同变更
     * @date 2019/12/7 3:31 PM
     */
    @PostMapping("modify")
    public RestResponse modify(@RequestBody Contracts contracts) {
        return contractService.modify(contracts);
    }

    /**
     * @param id 合同id
     * @return RestResponse 合同详情
     * @description 查询合同详情
     * @date 2019/12/6 4:46 PM
     */
    @PostMapping("detail/{id}")
    public RestResponse detail(@PathVariable(name = "id") Long id) {
        return contractService.detail(id);
    }

}
