package cn.com.ty.lift.system.utils;

import org.apache.commons.lang3.StringUtils;

import javax.servlet.http.HttpServletRequest;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author huangyuan
 * @date 2019-12-02
 * @description 项目工具类
 */
public class ProjectUtils {

    /**
     * @param
     * @return
     * @description 通过id字符串，获取long型id列表
     * @date 2019/11/27 10:03 AM
     */
    public static List<Long> getLongIdFromIds(String ids) {
        List<Long> longIdList = new ArrayList<>();
        if (StringUtils.isNotBlank(ids)) {
            String[] idArray = ids.split(",");
            for (String id : idArray) {
                longIdList.add(Long.parseLong(id));
            }
        }
        return longIdList;
    }

    /**
     * 将对象集合转化为attr->List<Obj>的map形式，通过特定属性给对象归类
     *
     * @param objList
     * @param attrName:属性名
     * @param parameterTypes
     * @return Map
     * @throws
     * @author huangy
     * @date 2018年12月19日
     */
    public static Map attrToListMap(List objList, String attrName, Class<?>... parameterTypes) {
        Map map = new HashMap<>();
        try {
            if (objList != null && objList.size() > 0) {
                for (Object o : objList) {
                    Class<?> classObj = o.getClass();
                    //获取属性get方法
                    String methodName = PojoUtils.attrGetMethodName(attrName);
                    Method method = classObj.getMethod(methodName, parameterTypes);
                    Object attr = method.invoke(o, parameterTypes);
                    //在map中获取对象集合
                    List objInfoList = (List) map.get(attr);
                    if (objInfoList == null) {
                        objInfoList = new ArrayList();
                    }
                    objInfoList.add(o);
                    map.put(attr, objInfoList);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return map;
    }

    /**
     *  将对象集合转化为attribute->Object的map
     *@author huangy
     *@date 2018年12月19日
     *@param objList
     *@param attrName:属性名称
     *@param parameterTypes
     *@return Map
     *@throws
     */
    public static Map attrToObjMap(List objList, String attrName, Class<?>... parameterTypes){

        Map<Object, Object> map = new HashMap<>();
        try {
            if(objList != null && objList.size() > 0) {
                for(Object o: objList) {
                    Class<?> classObj = o.getClass();
                    Method method = classObj.getMethod(PojoUtils.attrGetMethodName(attrName), parameterTypes);
                    Object attr = method.invoke(o, parameterTypes);
                    map.put(attr, o);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return map;

    }

    /**
     * 通过集合对象集合获取对象id集合
     *
     * @param objList
     * @param attrName
     * @param parameterTypes
     * @return List<? extends Object>
     * @throws
     * @author huangy
     */
    public static List getAttrList(List objList, String attrName, Class<?>... parameterTypes) {
        List idList = new ArrayList();
        if (objList != null && objList.size() > 0) {
            for (Object o : objList) {
                try {
                    Class<?> classObj = o.getClass();
                    Method method = classObj.getMethod(PojoUtils.attrGetMethodName(attrName), parameterTypes);
                    Object id = method.invoke(o, parameterTypes);
                    idList.add(id);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        }
        return idList;
    }

    /***
     * @description 通过request获取ip
     * @date 2019-12-10
     * @param request 请求对象
     * @return
     */
    public static String getIpAddress(HttpServletRequest request) {
        String ip = request.getHeader("x-forwarded-for");
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("WL-Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("HTTP_CLIENT_IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("HTTP_X_FORWARDED_FOR");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getRemoteAddr();
        }
        return ip;
    }

}
